@@ -127,7 +127,7 @@ def scatterd(x,
     fig = None
     if len(x)!=len(y): raise Exception('[scatterd] >Error: input parameter x should be the same size of y.')
     if s is None: raise Exception('[scatterd] >Error: input parameter s(ize) should have value >0.')
-    if c is None: raise Exception('[scatterd] >Error: input parameter c(olors) should be not None.')
+    if c is None: raise Exception('[scatterd] >Error: input parameter c(olors) can not be None.')
     if isinstance(c, str): raise Exception('[scatterd] >Error: input parameter c(olors) should be RGB of type tuple [0,0,0] .')
     if not isinstance(s, int) and len(s)!=len(x): raise Exception('[scatterd] >Error: input parameter s(ize) should be of same size of X.')
     if (z is not None) and len(x)!=len(z): raise Exception('[scatterd] >Error: input parameter z should be the same size of x and y.')
@@ -216,8 +216,8 @@ def _set_figure_properties(X, labels, fontcolor, fontsize, xlabel, ylabel, title
 # %% Setup colors
 def set_colors(X, labels, fontcolor, c, cmap, gradient=None):
     """Set colors."""
-    # Create unqiue colors for labels
-    if len(np.unique(labels))>1:
+    # Create unqiue colors for labels if there are multiple classes or in case cmap and gradient is used.
+    if (len(np.unique(labels))>1) or (len(c)==1 and isinstance(c, list) and (cmap is not None) and (gradient is not None)):
         c_rgb, _ = colourmap.fromlist(labels, cmap=cmap, method='matplotlib', gradient=gradient)
     elif len(c)==3 and (isinstance(c[0], int) or isinstance(c[0], float)):
         c_rgb = np.repeat([c], X.shape[0], axis=0).reshape(-1, 3)
